aiojaeger
=========
.. image:: https://github.com/pavkazzz/aiojaeger/workflows/Python%20package/badge.svg
    :target:  https://github.com/pavkazzz/aiojaeger/workflows
.. image:: https://codecov.io/gh/aio-libs/aiojaeger/branch/master/graph/badge.svg
    :target: https://codecov.io/gh/aio-libs/aiojaeger
.. image:: https://api.codeclimate.com/v1/badges/1ff813d5cad2d702cbf1/maintainability
   :target: https://codeclimate.com/github/aio-libs/aiojaeger/maintainability
   :alt: Maintainability
.. image:: https://img.shields.io/pypi/v/aiojaeger.svg
    :target: https://pypi.python.org/pypi/aiojaeger
.. image:: https://readthedocs.org/projects/aiojaeger/badge/?version=latest
    :target: http://aiojaeger.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Requirements
------------

* Python_ 3.7+
* aiohttp_
* pydanctic_
* thriftpy2_


.. _PEP492: https://www.python.org/dev/peps/pep-0492/
.. _Python: https://www.python.org
.. _aiohttp: https://github.com/KeepSafe/aiohttp
.. _pydanctic: https://github.com/samuelcolvin/aiohttp
.. _thriftpy2: https://github.com/Thriftpy/aiohttp
.. _asyncio: http://docs.python.org/3.8/library/asyncio.html
.. _uvloop: https://github.com/MagicStack/uvloop
.. _jaeger: http://jaeger.readthedocs.io/en/latest/
